@@ -1,6 +1,10 @@
 require 'spec_helper'
 
 describe Specinfra::Backend::Exec do
+  before :all do
+    set :backend, :exec
+  end
+
   describe '#build_command' do
     context 'with simple command' do
       it 'should escape spaces' do
@@ -12,6 +16,10 @@ describe Specinfra::Backend::Exec do
       it 'should escape special chars' do
         expect(Specinfra.backend.build_command('test ! -f /etc/selinux/config || (getenforce | grep -i -- disabled && grep -i -- ^SELINUX=disabled$ /etc/selinux/config)')).to eq '/bin/sh -c test\ \!\ -f\ /etc/selinux/config\ \|\|\ \(getenforce\ \|\ grep\ -i\ --\ disabled\ \&\&\ grep\ -i\ --\ \^SELINUX\=disabled\$\ /etc/selinux/config\)'
       end
+
+      it 'should escape quotes' do
+        expect(Specinfra.backend.build_command(%Q{find /etc/apt/ -name \*.list | xargs grep -o -E "^deb +[\\"']?http://ppa.launchpad.net/gluster/glusterfs-3.7"})).to eq('/bin/sh -c find\ /etc/apt/\ -name\ \*.list\ \|\ xargs\ grep\ -o\ -E\ \"\^deb\ \+\[\\\\\"\\\'\]\?http://ppa.launchpad.net/gluster/glusterfs-3.7\"')
+      end
     end
 
     context 'with custom shell' do
@@ -42,6 +50,34 @@ describe Specinfra::Backend::Exec do
       end
     end
 
+    context 'with an interactive shell' do
+      before do
+        RSpec.configure {|c| c.interactive_shell = true }
+      end
+
+      after do
+        RSpec.configure {|c| c.interactive_shell = nil }
+      end
+
+      it 'should emulate an interactive shell' do
+        expect(Specinfra.backend.build_command('test -f /etc/passwd')).to eq '/bin/sh -i -c test\ -f\ /etc/passwd'
+      end
+    end
+
+    context 'with an login shell' do
+      before do
+        RSpec.configure {|c| c.login_shell = true }
+      end
+
+      after do
+        RSpec.configure {|c| c.login_shell = nil }
+      end
+
+      it 'should emulate an login shell' do
+        expect(Specinfra.backend.build_command('test -f /etc/passwd')).to eq '/bin/sh -l -c test\ -f\ /etc/passwd'
+      end
+    end
+
     context 'with custom path' do
       before do
         RSpec.configure {|c| c.path = '/opt/bin:/opt/foo/bin:$PATH' }
@@ -75,14 +111,15 @@ end
 describe 'os' do
   before do
     # clear os information cache
-    property[:os_by_host] = {}
+    property[:os] = nil
+    Specinfra.configuration.instance_variable_set(:@os, nil)
+    Specinfra.backend.instance_variable_set(:@os_info, nil)
   end
 
   context 'test ubuntu with lsb_release command' do
-    subject { os }
-    it do
-      expect(Specinfra.backend).to receive(:run_command).at_least(1).times do |args|
-        if ['ls /etc/debian_version', 'lsb_release -ir'].include? args
+    before do
+      allow(Specinfra.backend).to receive(:run_command) do |args|
+        if ['cat /etc/debian_version', 'lsb_release -ir'].include? args
           double(
             :run_command_response,
             :success? => true,
@@ -94,18 +131,18 @@ describe 'os' do
           double :run_command_response, :success? => false, :stdout => nil
         end
       end
+    end
+    subject! { os }
+    it do
+      expect(Specinfra.backend).to have_received(:run_command).at_least(1).times
       should eq({:family => 'ubuntu', :release => '12.04', :arch => 'x86_64' })
     end
   end
 
   context 'test ubuntu with /etc/lsb-release' do
     before do
-      property[:os] = nil
-    end
-    subject { os }
-    it do
-      expect(Specinfra.backend).to receive(:run_command).at_least(1).times do |args|
-        if ['ls /etc/debian_version', 'cat /etc/lsb-release'].include? args
+      allow(Specinfra.backend).to receive(:run_command) do |args|
+        if ['cat /etc/debian_version', 'cat /etc/lsb-release'].include? args
           double(
             :run_command_response,
             :success? => true,
@@ -122,27 +159,30 @@ EOF
           double :run_command_response, :success? => false, :stdout => nil
         end
       end
+    end
+    subject! { os }
+    it do
+      expect(Specinfra.backend).to have_received(:run_command).at_least(1).times
       should eq({:family => 'ubuntu', :release => '12.04', :arch => 'x86_64' })
     end
   end
 
   context 'test debian (no lsb_release or lsb-release)' do
     before do
-      property[:os] = nil
-    end
-    subject { os }
-    it do
-      expect(Specinfra.backend).to receive(:run_command).at_least(1).times do |args|
-        if args == 'ls /etc/debian_version'
-          double :run_command_response, :success? => true, :stdout => nil
+      allow(Specinfra.backend).to receive(:run_command) do |args|
+        if args == 'cat /etc/debian_version'
+          double :run_command_response, :success? => true, :stdout => "8.5\n"
         elsif args == 'uname -m'
           double :run_command_response, :success? => true, :stdout => "x86_64\n"
         else
           double :run_command_response, :success? => false, :stdout => nil
         end
       end
-      should eq({:family => 'debian', :release => nil, :arch => 'x86_64' })
+    end
+    subject! { os }
+    it do
+      expect(Specinfra.backend).to have_received(:run_command).at_least(1).times
+      should eq({:family => 'debian', :release => '8.5', :arch => 'x86_64' })
     end
   end
 end
-
